@@ -131,7 +131,7 @@ class TextCategorizer(TrainablePipe):
 
         DOCS: https://spacy.io/api/textcategorizer#labels
         """
-        return tuple(self.cfg["labels"])
+        return tuple(self.cfg["labels"])  # type: ignore[arg-type, return-value]
 
     @property
     def label_data(self) -> List[str]:
@@ -139,7 +139,7 @@ class TextCategorizer(TrainablePipe):
 
         DOCS: https://spacy.io/api/textcategorizer#label_data
         """
-        return self.labels
+        return self.labels  # type: ignore[return-value]
 
     def predict(self, docs: Iterable[Doc]):
         """Apply the pipeline's model to a batch of docs, without modifying them.
@@ -153,7 +153,7 @@ class TextCategorizer(TrainablePipe):
             # Handle cases where there are no tokens in any docs.
             tensors = [doc.tensor for doc in docs]
             xp = get_array_module(tensors)
-            scores = xp.zeros((len(docs), len(self.labels)))
+            scores = xp.zeros((len(list(docs)), len(self.labels)))
             return scores
         scores = self.model.predict(docs)
         scores = self.model.ops.asarray(scores)
@@ -230,8 +230,9 @@ class TextCategorizer(TrainablePipe):
 
         DOCS: https://spacy.io/api/textcategorizer#rehearse
         """
-        if losses is not None:
-            losses.setdefault(self.name, 0.0)
+        if losses is None:
+            losses = {}
+        losses.setdefault(self.name, 0.0)
         if self._rehearsal_model is None:
             return losses
         validate_examples(examples, "TextCategorizer.rehearse")
@@ -247,23 +248,23 @@ class TextCategorizer(TrainablePipe):
         bp_scores(gradient)
         if sgd is not None:
             self.finish_update(sgd)
-        if losses is not None:
-            losses[self.name] += (gradient ** 2).sum()
+        losses[self.name] += (gradient ** 2).sum()
         return losses
 
     def _examples_to_truth(
-        self, examples: List[Example]
+        self, examples: Iterable[Example]
     ) -> Tuple[numpy.ndarray, numpy.ndarray]:
-        truths = numpy.zeros((len(examples), len(self.labels)), dtype="f")
-        not_missing = numpy.ones((len(examples), len(self.labels)), dtype="f")
+        nr_examples = len(list(examples))
+        truths = numpy.zeros((nr_examples, len(self.labels)), dtype="f")
+        not_missing = numpy.ones((nr_examples, len(self.labels)), dtype="f")
         for i, eg in enumerate(examples):
             for j, label in enumerate(self.labels):
                 if label in eg.reference.cats:
                     truths[i, j] = eg.reference.cats[label]
                 else:
                     not_missing[i, j] = 0.0
-        truths = self.model.ops.asarray(truths)
-        return truths, not_missing
+        truths = self.model.ops.asarray(truths)  # type: ignore
+        return truths, not_missing  # type: ignore
 
     def get_loss(self, examples: Iterable[Example], scores) -> Tuple[float, float]:
         """Find the loss and gradient of loss for the batch of documents and
@@ -278,7 +279,7 @@ class TextCategorizer(TrainablePipe):
         validate_examples(examples, "TextCategorizer.get_loss")
         self._validate_categories(examples)
         truths, not_missing = self._examples_to_truth(examples)
-        not_missing = self.model.ops.asarray(not_missing)
+        not_missing = self.model.ops.asarray(not_missing)  # type: ignore
         d_scores = (scores - truths) / scores.shape[0]
         d_scores *= not_missing
         mean_square_error = (d_scores ** 2).sum(axis=1).mean()
@@ -297,11 +298,9 @@ class TextCategorizer(TrainablePipe):
         if label in self.labels:
             return 0
         self._allow_extra_label()
-        self.cfg["labels"].append(label)
+        self.cfg["labels"].append(label)  # type: ignore[attr-defined]
         if self.model and "resize_output" in self.model.attrs:
-            self.model = self.model.attrs["resize_output"](
-                self.model, len(self.cfg["labels"])
-            )
+            self.model = self.model.attrs["resize_output"](self.model, len(self.labels))
         self.vocab.strings.add(label)
         return 1
 
@@ -374,7 +373,7 @@ class TextCategorizer(TrainablePipe):
             **kwargs,
         )
 
-    def _validate_categories(self, examples: List[Example]):
+    def _validate_categories(self, examples: Iterable[Example]):
         """Check whether the provided examples all have single-label cats annotations."""
         for ex in examples:
             if list(ex.reference.cats.values()).count(1.0) > 1:
