@@ -3,7 +3,13 @@ from spacy.util import get_lang_class
 
 
 def pytest_addoption(parser):
-    parser.addoption("--slow", action="store_true", help="include slow tests")
+    try:
+        parser.addoption("--slow", action="store_true", help="include slow tests")
+        parser.addoption("--issue", action="store", help="test specific issues")
+    # Options are already added, e.g. if conftest is copied in a build pipeline
+    # and runs twice
+    except ValueError:
+        pass
 
 
 def pytest_runtest_setup(item):
@@ -16,10 +22,24 @@ def pytest_runtest_setup(item):
         # options weren't given.
         return item.config.getoption(f"--{opt}", False)
 
+    # Integration of boolean flags
     for opt in ["slow"]:
         if opt in item.keywords and not getopt(opt):
             pytest.skip(f"need --{opt} option to run")
 
+    # Special integration to mark tests with issue numbers
+    issues = getopt("issue")
+    if isinstance(issues, str):
+        if "issue" in item.keywords:
+            # Convert issues provided on the CLI to list of ints
+            issue_nos = [int(issue.strip()) for issue in issues.split(",")]
+            # Get all issues specified by decorators and check if they're provided
+            issue_refs = [mark.args[0] for mark in item.iter_markers(name="issue")]
+            if not any([ref in issue_nos for ref in issue_refs]):
+                pytest.skip(f"not referencing specified issues: {issue_nos}")
+        else:
+            pytest.skip("not referencing any issues")
+
 
 # Fixtures for language tokenizers (languages sorted alphabetically)
 
@@ -125,6 +145,11 @@ def ga_tokenizer():
     return get_lang_class("ga")().tokenizer
 
 
+@pytest.fixture(scope="session")
+def grc_tokenizer():
+    return get_lang_class("grc")().tokenizer
+
+
 @pytest.fixture(scope="session")
 def gu_tokenizer():
     return get_lang_class("gu")().tokenizer
@@ -202,6 +227,11 @@ def ne_tokenizer():
     return get_lang_class("ne")().tokenizer
 
 
+@pytest.fixture(scope="session")
+def nl_vocab():
+    return get_lang_class("nl")().vocab
+
+
 @pytest.fixture(scope="session")
 def nl_tokenizer():
     return get_lang_class("nl")().tokenizer
@@ -281,11 +311,24 @@ def uk_tokenizer():
     return get_lang_class("uk")().tokenizer
 
 
+@pytest.fixture
+def uk_lemmatizer():
+    pytest.importorskip("pymorphy2")
+    pytest.importorskip("pymorphy2_dicts_uk")
+    return get_lang_class("uk")().add_pipe("lemmatizer")
+
+
 @pytest.fixture(scope="session")
 def ur_tokenizer():
     return get_lang_class("ur")().tokenizer
 
 
+@pytest.fixture(scope="session")
+def vi_tokenizer():
+    pytest.importorskip("pyvi")
+    return get_lang_class("vi")().tokenizer
+
+
 @pytest.fixture(scope="session")
 def yo_tokenizer():
     return get_lang_class("yo")().tokenizer
