@@ -102,7 +102,7 @@ def console_logger(progress_bar: bool = False):
 
 
 @registry.loggers("spacy.WandbLogger.v2")
-def wandb_logger(
+def wandb_logger_v2(
     project_name: str,
     remove_config_values: List[str] = [],
     model_log_interval: Optional[int] = None,
@@ -180,7 +180,7 @@ def wandb_logger(
 
 
 @registry.loggers("spacy.WandbLogger.v3")
-def wandb_logger(
+def wandb_logger_v3(
     project_name: str,
     remove_config_values: List[str] = [],
     model_log_interval: Optional[int] = None,
@@ -206,7 +206,9 @@ def wandb_logger(
         for field in remove_config_values:
             del config_dot[field]
         config = util.dot_to_dict(config_dot)
-        run = wandb.init(project=project_name, config=config, entity=entity, reinit=True)
+        run = wandb.init(
+            project=project_name, config=config, entity=entity, reinit=True
+        )
 
         if run_name:
             wandb.run.name = run_name
